@@ -3,6 +3,7 @@
 """
 Hardware base class
 """
+import configparser
 import re
 import os
 import types
@@ -15,6 +16,7 @@ import random
 from openrazer_daemon.dbus_services.service import DBusService
 import openrazer_daemon.dbus_services.dbus_methods
 from openrazer_daemon.misc import effect_sync
+from openrazer_daemon.misc.battery_notifier import BatteryManager as _BatteryManager
 
 
 # pylint: disable=too-many-instance-attributes
@@ -35,7 +37,9 @@ class RazerDevice(DBusService):
     USB_PID = None
     HAS_MATRIX = False
     DEDICATED_MACRO_KEYS = False
-    MATRIX_DIMS = [-1, -1]
+    MATRIX_DIMS = None
+    POLL_RATES = None
+    DPI_MAX = None
 
     WAVE_DIRS = (1, 2)
 
@@ -57,9 +61,11 @@ class RazerDevice(DBusService):
         self._observer_list = []
         self._effect_sync_propagate_up = False
         self._disable_notifications = False
+        self._disable_persistence = False
         self.additional_interfaces = []
         if additional_interfaces is not None:
             self.additional_interfaces.extend(additional_interfaces)
+        self._battery_manager = None
 
         self.config = config
         self.persistence = persistence
@@ -102,6 +108,8 @@ class RazerDevice(DBusService):
             self.dpi = [1800, 1800]
 
         self.poll_rate = 500
+        if 'set_poll_rate' in self.METHODS and not self.POLL_RATES:
+            self.POLL_RATES = [125, 500, 1000]
 
         self._effect_sync = effect_sync.EffectSync(self, device_number)
 
@@ -149,13 +157,22 @@ class RazerDevice(DBusService):
         }
 
         effect_methods = {
-            "backlight": {
+            "backlight_chroma": {
                 ('razer.device.lighting.chroma', 'getEffect', self.get_current_effect, None, 's'),
                 ('razer.device.lighting.chroma', 'getEffectColors', self.get_current_effect_colors, None, 'ay'),
                 ('razer.device.lighting.chroma', 'getEffectSpeed', self.get_current_effect_speed, None, 'i'),
                 ('razer.device.lighting.chroma', 'getWaveDir', self.get_current_wave_dir, None, 'i'),
             },
 
+            "backlight": {
+                # Intentionally using the same underlying methods as backlight_chroma.
+                # Both refer to the 'backlight' LED internally but partially exist separately due to historical reasons.
+                ('razer.device.lighting.backlight', 'getBacklightEffect', self.get_current_effect, None, 's'),
+                ('razer.device.lighting.backlight', 'getBacklightEffectColors', self.get_current_effect_colors, None, 'ay'),
+                ('razer.device.lighting.backlight', 'getBacklightEffectSpeed', self.get_current_effect_speed, None, 'i'),
+                ('razer.device.lighting.backlight', 'getBacklightWaveDir', self.get_current_wave_dir, None, 'i'),
+            },
+
             "logo": {
                 ('razer.device.lighting.logo', 'getLogoEffect', self.get_current_logo_effect, None, 's'),
                 ('razer.device.lighting.logo', 'getLogoEffectColors', self.get_current_logo_effect_colors, None, 'ay'),
@@ -213,12 +230,15 @@ class RazerDevice(DBusService):
         # this check is separate from the rest because backlight effects don't have prefixes in their names
         if 'set_static_effect' in self.METHODS or 'bw_set_static' in self.METHODS:
             self.zone["backlight"]["present"] = True
-            for m in effect_methods["backlight"]:
+            for m in effect_methods["backlight_chroma"]:
                 self.logger.debug("Adding {}.{} method to DBus".format(m[0], m[1]))
                 self.add_dbus_method(m[0], m[1], m[2], in_signature=m[3], out_signature=m[4])
 
-        for i in self.ZONES[1:]:
-            if 'set_' + i + '_static' in self.METHODS or 'set_' + i + '_static_naga_hex_v2' in self.METHODS or 'set_' + i + '_active' in self.METHODS:
+        for i in self.ZONES:
+            if 'set_' + i + '_static_classic' in self.METHODS \
+                    or 'set_' + i + '_static' in self.METHODS \
+                    or 'set_' + i + '_active' in self.METHODS \
+                    or 'set_' + i + '_on' in self.METHODS:
                 self.zone[i]["present"] = True
                 for m in effect_methods[i]:
                     self.logger.debug("Adding {}.{} method to DBus".format(m[0], m[1]))
@@ -233,22 +253,14 @@ class RazerDevice(DBusService):
                 try:
                     self.dpi[0] = int(self.persistence[self.storage_name]['dpi_x'])
                     self.dpi[1] = int(self.persistence[self.storage_name]['dpi_y'])
-                except KeyError:
-                    pass
+                except (KeyError, configparser.NoOptionError):
+                    self.logger.info("Failed to get DPI from persistence storage, using default.")
 
             if 'set_poll_rate' in self.METHODS:
                 try:
                     self.poll_rate = int(self.persistence[self.storage_name]['poll_rate'])
-                except KeyError:
-                    pass
-
-        dpi_func = getattr(self, "setDPI", None)
-        if dpi_func is not None:
-            dpi_func(self.dpi[0], self.dpi[1])
-
-        poll_rate_func = getattr(self, "setPollRate", None)
-        if poll_rate_func is not None:
-            poll_rate_func(self.poll_rate)
+                except (KeyError, configparser.NoOptionError):
+                    self.logger.info("Failed to get poll rate from persistence storage, using default.")
 
         # load last effects
         for i in self.ZONES:
@@ -258,20 +270,20 @@ class RazerDevice(DBusService):
                     # try reading the effect name from the persistence
                     try:
                         self.zone[i]["effect"] = self.persistence[self.storage_name][i + '_effect']
-                    except KeyError:
-                        pass
+                    except (KeyError, configparser.NoOptionError):
+                        self.logger.info("Failed to get " + i + " effect from persistence storage, using default.")
 
                     # zone active status
                     try:
-                        self.zone[i]["active"] = bool(self.persistence[self.storage_name][i + '_active'])
-                    except KeyError:
-                        pass
+                        self.zone[i]["active"] = self.persistence.getboolean(self.storage_name, i + '_active')
+                    except (KeyError, configparser.NoOptionError):
+                        self.logger.info("Failed to get " + i + " active from persistence storage, using default.")
 
                     # brightness
                     try:
                         self.zone[i]["brightness"] = float(self.persistence[self.storage_name][i + '_brightness'])
-                    except KeyError:
-                        pass
+                    except (KeyError, configparser.NoOptionError):
+                        self.logger.info("Failed to get " + i + " brightness from persistence storage, using default.")
 
                     # colors.
                     # these are stored as a string that must contain 9 numbers, separated with spaces.
@@ -285,44 +297,31 @@ class RazerDevice(DBusService):
                         # check if we have exactly 9 colors
                         if len(self.zone[i]["colors"]) != 9:
                             raise ValueError('There must be exactly 9 colors')
-
                     except ValueError:
                         # invalid colors. reinitialize
                         self.zone[i]["colors"] = [0, 255, 0, 0, 255, 255, 0, 0, 255]
                         self.logger.info("%s: Invalid colors; restoring to defaults.", self.__class__.__name__)
-                        pass
-
-                    except KeyError:
-                        pass
+                    except (KeyError, configparser.NoOptionError):
+                        self.logger.info("Failed to get " + i + " colors from persistence storage, using default.")
 
                     # speed
                     try:
                         self.zone[i]["speed"] = int(self.persistence[self.storage_name][i + '_speed'])
-
-                    except KeyError:
-                        pass
+                    except (KeyError, configparser.NoOptionError):
+                        self.logger.info("Failed to get " + i + " speed from persistence storage, using default.")
 
                     # wave direction
                     try:
                         self.zone[i]["wave_dir"] = int(self.persistence[self.storage_name][i + '_wave_dir'])
+                    except (KeyError, configparser.NoOptionError):
+                        self.logger.info("Failed to get " + i + " wave direction from persistence storage, using default.")
 
-                    except KeyError:
-                        pass
+        # Initialize battery manager if the device has support
+        if 'get_battery' in self.METHODS:
+            self._init_battery_manager()
 
-                if 'set_' + i + '_active' in self.METHODS:
-                    active_func = getattr(self, "set" + self.capitalize_first_char(i) + "Active", None)
-                    if active_func is not None:
-                        active_func(self.zone[i]["active"])
-
-                # load brightness level
-                bright_func = None
-                if i == "backlight":
-                    bright_func = getattr(self, "setBrightness", None)
-                elif 'set_' + i + '_brightness' in self.METHODS:
-                    bright_func = getattr(self, "set" + self.capitalize_first_char(i) + "Brightness", None)
-
-                if bright_func is not None:
-                    bright_func(self.zone[i]["brightness"])
+        self.restore_dpi_poll_rate()
+        self.restore_brightness()
 
         if self.config.getboolean('Startup', "restore_persistence") is True:
             self.restore_effect()
@@ -351,6 +350,77 @@ class RazerDevice(DBusService):
         """
         return self.DEDICATED_MACRO_KEYS
 
+    def restore_dpi_poll_rate(self):
+        """
+        Set the device DPI & poll rate to the saved value
+        """
+        dpi_func = getattr(self, "setDPI", None)
+        if dpi_func is not None:
+            # Constrain value in case the max has changed, e.g. wired/wireless might different maximums
+            if self.dpi[0] > self.DPI_MAX:
+                self.logger.warning("Constraining DPI X to maximum of " + str(self.DPI_MAX) + " because stored value " + str(self.dpi[0]) + " is larger.")
+                self.dpi[0] = self.DPI_MAX
+            if self.dpi[1] > self.DPI_MAX:
+                self.logger.warning("Constraining DPI Y to maximum of " + str(self.DPI_MAX) + " because stored value " + str(self.dpi[1]) + " is larger.")
+                self.dpi[1] = self.DPI_MAX
+
+            dpi_func(self.dpi[0], self.dpi[1])
+
+        poll_rate_func = getattr(self, "setPollRate", None)
+        if poll_rate_func is not None:
+            # Constrain value in case the available values have changed, e.g. wired/wireless might different values available
+            if self.poll_rate not in self.POLL_RATES:
+                self.logger.warning("Constraining poll rate because stored value " + str(self.poll_rate) + " is not available.")
+                self.poll_rate = min(self.POLL_RATES, key=lambda x: abs(x - self.poll_rate))
+
+            poll_rate_func(self.poll_rate)
+
+    def restore_brightness(self):
+        """
+        Set the device to the current brightness/active state.
+
+        This is used at launch time.
+        """
+        for i in self.ZONES:
+            if self.zone[i]["present"]:
+                # load active state
+                if 'set_' + i + '_active' in self.METHODS:
+                    active_func = getattr(self, "set" + self.capitalize_first_char(i) + "Active", None)
+                    if active_func is not None:
+                        active_func(self.zone[i]["active"])
+
+                # load brightness level
+                bright_func = None
+                if i == "backlight":
+                    bright_func = getattr(self, "setBrightness", None)
+                elif 'set_' + i + '_brightness' in self.METHODS:
+                    bright_func = getattr(self, "set" + self.capitalize_first_char(i) + "Brightness", None)
+
+                if bright_func is not None:
+                    bright_func(self.zone[i]["brightness"])
+
+    def disable_brightness(self):
+        """
+        Set brightness to 0 and/or active state to false.
+        """
+        for i in self.ZONES:
+            if self.zone[i]["present"]:
+                # set active state
+                if 'set_' + i + '_active' in self.METHODS:
+                    active_func = getattr(self, "set" + self.capitalize_first_char(i) + "Active", None)
+                    if active_func is not None:
+                        active_func(False)
+
+                # set brightness level
+                bright_func = None
+                if i == "backlight":
+                    bright_func = getattr(self, "setBrightness", None)
+                elif 'set_' + i + '_brightness' in self.METHODS:
+                    bright_func = getattr(self, "set" + self.capitalize_first_char(i) + "Brightness", None)
+
+                if bright_func is not None:
+                    bright_func(0)
+
     def restore_effect(self):
         """
         Set the device to the current effect
@@ -397,6 +467,8 @@ class RazerDevice(DBusService):
                             effect_func(speed)
                         elif effect == 'wave':
                             effect_func(wave_dir)
+                        elif effect == 'wheel':
+                            effect_func(wave_dir)
                         elif effect == 'rippleRandomColour':
                             # do nothing. this is handled in the ripple manager.
                             pass
@@ -435,6 +507,10 @@ class RazerDevice(DBusService):
         :param value: Value
         :type value: string
         """
+        if self._disable_persistence:
+            return
+        self.logger.debug("Set persistence (%s, %s, %s)", zone, key, value)
+
         self.persistence.status["changed"] = True
 
         if zone:
@@ -834,6 +910,26 @@ class RazerDevice(DBusService):
         """
         self._disable_notifications = value
 
+    @property
+    def disable_persistence(self):
+        """
+        Disable persistence flag
+
+        :return: Flag
+        :rtype: bool
+        """
+        return self._disable_persistence
+
+    @disable_persistence.setter
+    def disable_persistence(self, value):
+        """
+        Set the disable persistence flag
+
+        :param value: Disable
+        :type value: bool
+        """
+        self._disable_persistence = value
+
     def get_driver_path(self, driver_filename):
         """
         Get the path to a driver file
@@ -927,6 +1023,48 @@ class RazerDevice(DBusService):
 
             mode_file.write(bytes([mode_id, param]))
 
+    def _set_custom_effect(self):
+        """
+        Set the device to use custom LED matrix
+        """
+        # self.logger.debug("DBus call _set_custom_effect")
+
+        driver_path = self.get_driver_path('matrix_effect_custom')
+
+        payload = b'1'
+
+        with open(driver_path, 'wb') as driver_file:
+            driver_file.write(payload)
+
+    def _set_key_row(self, payload):
+        """
+        Set the RGB matrix on the device
+
+        Byte array like
+        [1, 255, 255, 00, 255, 255, 00, 255, 255, 00, 255, 255, 00, 255, 255, 00, 255, 255, 00, 255, 255, 00, 255, 255, 00,
+            255, 255, 00, 255, 255, 00, 255, 255, 00, 255, 255, 00, 255, 255, 00, 255, 255, 00, 255, 00, 00]
+
+        First byte is row, on firefly its always 1, on keyboard its 0-5
+        Then its 3byte groups of RGB
+        :param payload: Binary payload
+        :type payload: bytes
+        """
+        # self.logger.debug("DBus call set_key_row")
+
+        driver_path = self.get_driver_path('matrix_custom_frame')
+
+        with open(driver_path, 'wb') as driver_file:
+            driver_file.write(payload)
+
+    def _init_battery_manager(self):
+        """
+        Initializes the BatteryManager using the provided name
+        """
+        self._battery_manager = _BatteryManager(self, self._device_number, self.getDeviceName())  # pylint: disable=no-member
+        self._battery_manager.active = self.config.getboolean('Startup', 'battery_notifier', fallback=False)
+        self._battery_manager.frequency = self.config.getint('Startup', 'battery_notifier_freq', fallback=10 * 60)
+        self._battery_manager.percent = self.config.getint('Startup', 'battery_notifier_percent', fallback=33)
+
     def get_vid_pid(self):
         """
         Get the usb VID PID
@@ -975,26 +1113,38 @@ class RazerDevice(DBusService):
         Suspend device
         """
         self.logger.info("Suspending %s", self.__class__.__name__)
+        self.disable_notify = True
+        self.disable_persistence = True
+
+        self.disable_brightness()
         self._suspend_device()
 
+        self.disable_notify = False
+        self.disable_persistence = False
+
     def resume_device(self):
         """
         Resume device
         """
         self.logger.info("Resuming %s", self.__class__.__name__)
+        self.disable_notify = True
+        self.disable_persistence = True
+
+        self.restore_brightness()
         self._resume_device()
 
+        self.disable_notify = False
+        self.disable_persistence = False
+
     def _suspend_device(self):
         """
-        Suspend device
+        Override to implement custom suspend behavior
         """
-        raise NotImplementedError()
 
     def _resume_device(self):
         """
-        Resume device
+        Override to implement custom resume behavior
         """
-        raise NotImplementedError()
 
     def _close(self):
         """
@@ -1003,6 +1153,9 @@ class RazerDevice(DBusService):
         # Clear observer list
         self._observer_list.clear()
 
+        if self._battery_manager:
+            self._battery_manager.close()
+
     def close(self):
         """
         Close any resources opened by subclasses
@@ -1130,44 +1283,9 @@ class RazerDevice(DBusService):
         return "{0}:{1}".format(self.__class__.__name__, self.serial)
 
 
-class RazerDeviceSpecialBrightnessSuspend(RazerDevice):
-    """
-    Class for suspend using brightness
-
-    Suspend functions
-    """
-
-    def _suspend_device(self):
-        """
-        Suspend the device
-
-        Get the current brightness level, store it for later and then set the brightness to 0
-        """
-        self.suspend_args.clear()
-        self.suspend_args['brightness'] = openrazer_daemon.dbus_services.dbus_methods.get_brightness(self)
-
-        # Todo make it context?
-        self.disable_notify = True
-        openrazer_daemon.dbus_services.dbus_methods.set_brightness(self, 0)
-        self.disable_notify = False
-
-    def _resume_device(self):
-        """
-        Resume the device
-
-        Get the last known brightness and then set the brightness
-        """
-        brightness = self.suspend_args.get('brightness', 100)
-
-        self.disable_notify = True
-        openrazer_daemon.dbus_services.dbus_methods.set_brightness(self, brightness)
-        self.disable_notify = False
-
-
-class RazerDeviceBrightnessSuspend(RazerDeviceSpecialBrightnessSuspend):
+class RazerDeviceBrightnessSuspend(RazerDevice):
     """
     Class for devices that have get_brightness and set_brightness
-    Inherits from RazerDeviceSpecialBrightnessSuspend
     """
 
     def __init__(self, *args, **kwargs):
