@@ -22,46 +22,17 @@ class RazerKraken71(__RazerDevice):
 
     DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/229/229_kraken_71.png"
 
-    @staticmethod
-    def decode_bitfield(bitfield):
-        return {
-            'state': (bitfield & 0x01) == 0x01,
-            'breathing1': (bitfield & 0x02) == 0x02,
-            'spectrum': (bitfield & 0x04) == 0x04,
-            'sync': (bitfield & 0x08) == 0x08,
-            'breathing2': (bitfield & 0x10) == 0x10,
-            'breathing3': (bitfield & 0x20) == 0x20,
-        }
-
     def _suspend_device(self):
-        """
-        Suspend the device
-
-        Get the current brightness level, store it for later and then set the brightness to 0
-        """
         self.suspend_args.clear()
-
         self.suspend_args['effect'] = self.zone["backlight"]["effect"]
 
-        self.disable_notify = True
         _dbus_chroma.set_none_effect(self)
-        self.disable_notify = False
 
     def _resume_device(self):
-        """
-        Resume the device
-
-        Get the last known brightness and then set the brightness
-        """
-
         effect = self.suspend_args.get('effect', '')
-
-        self.disable_notify = True
         if effect == 'static':  # Static on classic is only 1 colour
             _dbus_chroma.set_static_effect(self, 0x00, 0x00, 0x00)
 
-        self.disable_notify = False
-
 
 class RazerKraken71Alternate(RazerKraken71):
     """
@@ -84,43 +55,17 @@ class RazerKraken71Chroma(__RazerDevice):
 
     DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/280/280_kraken_71_chroma.png"
 
-    @staticmethod
-    def decode_bitfield(bitfield):
-        return {
-            'state': (bitfield & 0x01) == 0x01,
-            'breathing1': (bitfield & 0x02) == 0x02,
-            'spectrum': (bitfield & 0x04) == 0x04,
-            'sync': (bitfield & 0x08) == 0x08,
-            'breathing2': (bitfield & 0x10) == 0x10,
-            'breathing3': (bitfield & 0x20) == 0x20,
-        }
-
     def _suspend_device(self):
-        """
-        Suspend the device
-
-        Get the current brightness level, store it for later and then set the brightness to 0
-        """
         self.suspend_args.clear()
-
         self.suspend_args['effect'] = self.zone["backlight"]["effect"]
         self.suspend_args['args'] = self.zone["backlight"]["colors"][0:3]
 
-        self.disable_notify = True
         _dbus_chroma.set_none_effect(self)
-        self.disable_notify = False
 
     def _resume_device(self):
-        """
-        Resume the device
-
-        Get the last known brightness and then set the brightness
-        """
-
         effect = self.suspend_args.get('effect', '')
         args = self.suspend_args.get('args', [])
 
-        self.disable_notify = True
         if effect == 'spectrum':
             _dbus_chroma.set_spectrum_effect(self)
         elif effect == 'static':
@@ -128,8 +73,6 @@ class RazerKraken71Chroma(__RazerDevice):
         elif effect == 'breathSingle':
             _dbus_chroma.set_breath_single_effect(self, *args)
 
-        self.disable_notify = False
-
 
 class RazerKraken71V2(__RazerDevice):
     """
@@ -145,25 +88,8 @@ class RazerKraken71V2(__RazerDevice):
 
     DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/729/729_kraken_71_v2.png"
 
-    @staticmethod
-    def decode_bitfield(bitfield):
-        return {
-            'state': (bitfield & 0x01) == 0x01,
-            'breathing1': (bitfield & 0x02) == 0x02,
-            'spectrum': (bitfield & 0x04) == 0x04,
-            'sync': (bitfield & 0x08) == 0x08,
-            'breathing2': (bitfield & 0x10) == 0x10,
-            'breathing3': (bitfield & 0x20) == 0x20,
-        }
-
     def _suspend_device(self):
-        """
-        Suspend the device
-
-        Get the current brightness level, store it for later and then set the brightness to 0
-        """
         self.suspend_args.clear()
-
         self.suspend_args['effect'] = self.zone["backlight"]["effect"]
         if self.suspend_args['effect'] == "breathDual":
             self.suspend_args['args'] = self.zone["backlight"]["colors"][0:6]
@@ -172,21 +98,12 @@ class RazerKraken71V2(__RazerDevice):
         else:
             self.suspend_args['args'] = self.zone["backlight"]["colors"][0:3]
 
-        self.disable_notify = True
         _dbus_chroma.set_none_effect(self)
-        self.disable_notify = False
 
     def _resume_device(self):
-        """
-        Resume the device
-
-        Get the last known brightness and then set the brightness
-        """
-
         effect = self.suspend_args.get('effect', '')
         args = self.suspend_args.get('args', [])
 
-        self.disable_notify = True
         if effect == 'spectrum':
             _dbus_chroma.set_spectrum_effect(self)
         elif effect == 'static':
@@ -198,8 +115,6 @@ class RazerKraken71V2(__RazerDevice):
         elif effect == 'breathTriple':
             _dbus_chroma.set_breath_triple_effect(self, *args)
 
-        self.disable_notify = False
-
 
 class RazerKrakenUltimate(__RazerDevice):
     """
@@ -216,25 +131,8 @@ class RazerKrakenUltimate(__RazerDevice):
 
     DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/1603/rzr_kraken_ultimate_render01_2019_resized.png"
 
-    @staticmethod
-    def decode_bitfield(bitfield):
-        return {
-            'state': (bitfield & 0x01) == 0x01,
-            'breathing1': (bitfield & 0x02) == 0x02,
-            'spectrum': (bitfield & 0x04) == 0x04,
-            'sync': (bitfield & 0x08) == 0x08,
-            'breathing2': (bitfield & 0x10) == 0x10,
-            'breathing3': (bitfield & 0x20) == 0x20,
-        }
-
     def _suspend_device(self):
-        """
-        Suspend the device
-
-        Get the current brightness level, store it for later and then set the brightness to 0
-        """
         self.suspend_args.clear()
-
         self.suspend_args['effect'] = self.zone["backlight"]["effect"]
         if self.suspend_args['effect'] == "breathDual":
             self.suspend_args['args'] = self.zone["backlight"]["colors"][0:6]
@@ -243,21 +141,12 @@ class RazerKrakenUltimate(__RazerDevice):
         else:
             self.suspend_args['args'] = self.zone["backlight"]["colors"][0:3]
 
-        self.disable_notify = True
         _dbus_chroma.set_none_effect(self)
-        self.disable_notify = False
 
     def _resume_device(self):
-        """
-        Resume the device
-
-        Get the last known brightness and then set the brightness
-        """
-
         effect = self.suspend_args.get('effect', '')
         args = self.suspend_args.get('args', [])
 
-        self.disable_notify = True
         if effect == 'spectrum':
             _dbus_chroma.set_spectrum_effect(self)
         elif effect == 'static':
@@ -269,8 +158,6 @@ class RazerKrakenUltimate(__RazerDevice):
         elif effect == 'breathTriple':
             _dbus_chroma.set_breath_triple_effect(self, *args)
 
-        self.disable_notify = False
-
 
 class RazerKrakenKittyEdition(__RazerDeviceBrightnessSuspend):
     """
