@@ -8,7 +8,6 @@ import re
 from openrazer_daemon.hardware.device_base import RazerDeviceBrightnessSuspend as _RazerDeviceBrightnessSuspend
 from openrazer_daemon.misc.key_event_management import KeyboardKeyManager as _KeyboardKeyManager, GamepadKeyManager as _GamepadKeyManager, OrbweaverKeyManager as _OrbweaverKeyManager
 from openrazer_daemon.misc.ripple_effect import RippleManager as _RippleManager
-from openrazer_daemon.misc.battery_notifier import BatteryManager as _BatteryManager
 
 
 class _MacroKeyboard(_RazerDeviceBrightnessSuspend):
@@ -44,6 +43,24 @@ class _MacroKeyboard(_RazerDeviceBrightnessSuspend):
 
         self.key_manager.close()
 
+    def _resume_device(self):
+        """
+        Restore device mode
+
+        Set device back to driver mode after e.g. suspend which resets the
+        device to default device mode.
+
+        NOTE: This is really the wrong place to put this, since this callback
+        is for screensaver unlock, and not for 'wake up from suspend' or
+        similar. Nevertheless for now this seems to be the best place for this
+        and should resolve some issues with macro keys not working after
+        suspend.
+        """
+        super()._resume_device()
+
+        self.logger.info('Putting device back into driver mode.')
+        self.set_device_mode(0x03, 0x00)  # Driver mode
+
 
 class _RippleKeyboard(_MacroKeyboard):
     """
@@ -55,6 +72,10 @@ class _RippleKeyboard(_MacroKeyboard):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
+        if not self.HAS_MATRIX:
+            # You can use _MacroKeyboard instead if the keyboard doesn't support matrix
+            raise RuntimeError("Cannot use RippleKeyboard without matrix capabilities")
+
         self.ripple_manager = _RippleManager(self, self._device_number)
 
         # we need to set the effect to ripple (if needed) after the ripple manager has started
@@ -292,7 +313,6 @@ class RazerBlackWidowUltimate2012(_MacroKeyboard):
     USB_VID = 0x1532
     USB_PID = 0x010D
     DEDICATED_MACRO_KEYS = True
-    MATRIX_DIMS = [6, 22]
     METHODS = ['get_device_type_keyboard', 'get_game_mode', 'set_game_mode', 'set_macro_mode', 'get_macro_mode',
                'get_macro_effect', 'set_macro_effect', 'bw_set_pulsate', 'bw_set_static', 'get_macros', 'delete_macro', 'add_macro']
 
@@ -308,7 +328,6 @@ class RazerBlackWidowStealth(_MacroKeyboard):
     USB_VID = 0x1532
     USB_PID = 0x011B
     DEDICATED_MACRO_KEYS = True
-    MATRIX_DIMS = [6, 22]
     METHODS = ['get_device_type_keyboard', 'get_game_mode', 'set_game_mode', 'set_macro_mode', 'get_macro_mode',
                'get_macro_effect', 'set_macro_effect', 'bw_set_pulsate', 'bw_set_static', 'get_macros', 'delete_macro', 'add_macro']
 
@@ -324,7 +343,6 @@ class RazerBlackWidowStealthEdition(_MacroKeyboard):
     USB_VID = 0x1532
     USB_PID = 0x010E
     DEDICATED_MACRO_KEYS = True
-    MATRIX_DIMS = [6, 22]
     METHODS = ['get_device_type_keyboard', 'get_game_mode', 'set_game_mode', 'set_macro_mode', 'get_macro_mode',
                'get_macro_effect', 'set_macro_effect', 'bw_set_pulsate', 'bw_set_static', 'get_macros', 'delete_macro', 'add_macro']
 
@@ -340,7 +358,6 @@ class RazerBlackWidowUltimate2013(_MacroKeyboard):
     USB_VID = 0x1532
     USB_PID = 0x011A
     DEDICATED_MACRO_KEYS = True
-    MATRIX_DIMS = [6, 22]
     METHODS = ['get_device_type_keyboard', 'get_game_mode', 'set_game_mode', 'set_macro_mode', 'get_macro_mode',
                'get_macro_effect', 'set_macro_effect', 'bw_set_pulsate', 'bw_set_static', 'get_macros', 'delete_macro', 'add_macro']
 
@@ -379,23 +396,10 @@ class RazerBlackWidowV3ProWired(_RippleKeyboard):
                'set_starlight_random_effect', 'set_starlight_single_effect', 'set_starlight_dual_effect',
                'set_ripple_effect', 'set_ripple_effect_random_colour',
                # Battery
-               'set_charge_effect', 'set_charge_colour', 'get_battery', 'is_charging', 'set_idle_time', 'set_low_battery_threshold']
+               'set_charge_effect', 'set_charge_colour', 'get_battery', 'is_charging', 'set_low_battery_threshold']
 
     DEVICE_IMAGE = "https://dl.razerzone.com/src/3809-1-EN-v1.png"
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
-        self._battery_manager = _BatteryManager(self, self._device_number, "Razer BlackWidow V3 Pro (Wired)")
-        self._battery_manager.active = self.config.getboolean('Startup', 'battery_notifier', fallback=False)
-        self._battery_manager.frequency = self.config.getint('Startup', 'battery_notifier_freq', fallback=10 * 60)
-        self._battery_manager.percent = self.config.getint('Startup', 'battery_notifier_percent', fallback=33)
-
-    def _close(self):
-        super()._close()
-
-        self._battery_manager.close()
-
 
 class RazerBlackWidowChroma(_RippleKeyboard):
     """
@@ -758,6 +762,31 @@ class RazerOrnataV2(_RippleKeyboard):
     DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/1672/ornata-v2.png"
 
 
+class RazerOrnataV3X(_MacroKeyboard):
+    """
+    Class for the Razer Ornata V3 X
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*Razer_Ornata_V3_X(-if01)?-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x0294
+    HAS_MATRIX = True
+    MATRIX_DIMS = [1, 1]
+    METHODS = ['get_device_type_keyboard', 'set_static_effect', 'set_spectrum_effect',
+               'set_none_effect', 'set_breath_single_effect', 'set_breath_dual_effect',
+               'set_custom_effect', 'set_key_row', 'get_game_mode', 'set_game_mode', 'get_macro_mode', 'set_macro_mode',
+               'get_macro_effect', 'set_macro_effect', 'get_macros', 'delete_macro', 'add_macro']
+
+    DEVICE_IMAGE = "https://dl.razerzone.com/src/6071-1-en-v1.png"
+
+
+class RazerOrnataV3X_Alternate(RazerOrnataV3X):
+    """
+    Class for the Razer Ornata V3 X (Alternate)
+    """
+    USB_PID = 0x02A2
+
+
 class RazerHuntsmanElite(_RippleKeyboard):
     """
     Class for the Razer Huntsman Elite
@@ -904,22 +933,6 @@ class RazerBlackWidowV3MiniHyperspeed(_RippleKeyboard):
 
     DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/1777/500x500-blackwidowv3mini.png"
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
-        self._battery_manager = _BatteryManager(self, self._device_number, 'Razer BlackWidow V3 Mini Hyperspeed')
-        self._battery_manager.active = self.config.getboolean('Startup', 'battery_notifier', fallback=False)
-        self._battery_manager.frequency = self.config.getint('Startup', 'battery_notifier_freq', fallback=10 * 60)
-        self._battery_manager.percent = self.config.getint('Startup', 'battery_notifier_percent', fallback=33)
-
-    def _close(self):
-        """
-        Close the key manager
-        """
-        super()._close()
-
-        self._battery_manager.close()
-
 
 class RazerBlackWidowV3MiniHyperspeedWireless(RazerBlackWidowV3MiniHyperspeed):
     """
@@ -990,7 +1003,7 @@ class RazerCynosaV2(_RippleKeyboard):
     DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/1694/1694-2.png"
 
 
-class RazerCynosaLite(_RippleKeyboard):
+class RazerCynosaLite(_MacroKeyboard):
     """
     Class for the Razer Cynosa Lite
     """
@@ -1006,7 +1019,7 @@ class RazerCynosaLite(_RippleKeyboard):
     DEVICE_IMAGE = "https://assets2.razerzone.com/images/og-image/cynosa-lite-OGimage.jpg"
 
 
-class RazerBlackWidowLite(_RippleKeyboard):
+class RazerBlackWidowLite(_MacroKeyboard):
     """
     Class for the Razer BlackWidow Lite
     """
@@ -1113,6 +1126,20 @@ class RazerDeathStalkerExpert(_MacroKeyboard):
     DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/49/49_razer_deathstalker.png"
 
 
+class RazerDeathStalkerEssential(_MacroKeyboard):
+    """
+    Class for the Razer DeathStalker/DeathStalker Essential
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*Razer_DeathStalker(-if01)?-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x0118
+    METHODS = ['get_device_type_keyboard', 'get_game_mode', 'set_game_mode', 'set_macro_mode', 'get_macro_mode',
+               'get_macro_effect', 'set_macro_effect', 'bw_set_pulsate', 'bw_set_static', 'get_macros', 'delete_macro', 'add_macro']
+
+    DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/49/49_razer_deathstalker.png"
+
+
 class RazerDeathStalkerChroma(_RippleKeyboard):
     """
     Class for the Razer DeathStalker Chroma
@@ -1152,6 +1179,64 @@ class RazerDeathStalkerV2(_RippleKeyboard):
     DEVICE_IMAGE = "https://dl.razerzone.com/src/6118/6118-1-en-v1.png"
 
 
+class RazerDeathStalkerV2ProWired(_RippleKeyboard):
+    """
+    Class for the Razer DeathStalker V2 Pro (Wired)
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*DSV2_Pro_000000000000-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x0292
+    HAS_MATRIX = True
+    MATRIX_DIMS = [6, 22]
+    METHODS = ['get_device_type_keyboard', 'set_wave_effect', 'set_static_effect', 'set_spectrum_effect',
+               'set_reactive_effect', 'set_none_effect', 'set_breath_random_effect', 'set_breath_single_effect', 'set_breath_dual_effect',
+               'set_custom_effect', 'set_key_row', 'get_game_mode', 'set_game_mode', 'get_macro_mode', 'set_macro_mode',
+               'get_macro_effect', 'set_macro_effect', 'get_macros', 'delete_macro', 'add_macro',
+               'set_starlight_random_effect', 'set_starlight_single_effect', 'set_starlight_dual_effect',
+               'set_ripple_effect', 'set_ripple_effect_random_colour',
+               # Battery
+               'get_battery', 'is_charging']
+
+    DEVICE_IMAGE = "https://dl.razerzone.com/src/6118/6118-1-en-v1.png"
+
+
+class RazerDeathStalkerV2ProWireless(RazerDeathStalkerV2ProWired):
+    """
+    Class for the Razer DeathStalker V2 Pro (Wireless)
+    """
+    USB_PID = 0x0290
+
+
+class RazerDeathStalkerV2ProTKLWired(_RippleKeyboard):
+    """
+    Class for the Razer DeathStalker V2 Pro TKL (Wired)
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*DSV2_Pro_000000000000-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x0298
+    HAS_MATRIX = True
+    MATRIX_DIMS = [6, 17]
+    METHODS = ['get_device_type_keyboard', 'set_wave_effect', 'set_static_effect', 'set_spectrum_effect',
+               'set_reactive_effect', 'set_none_effect', 'set_breath_random_effect', 'set_breath_single_effect', 'set_breath_dual_effect',
+               'set_custom_effect', 'set_key_row', 'get_game_mode', 'set_game_mode', 'get_macro_mode', 'set_macro_mode',
+               'get_macro_effect', 'set_macro_effect', 'get_macros', 'delete_macro', 'add_macro',
+               'set_starlight_random_effect', 'set_starlight_single_effect', 'set_starlight_dual_effect',
+               'set_ripple_effect', 'set_ripple_effect_random_colour',
+               # Battery
+               'get_battery', 'is_charging']
+
+    DEVICE_IMAGE = "https://dl.razerzone.com/src/6117/6117-1-en-v1.png"
+
+
+class RazerDeathStalkerV2ProTKLWireless(RazerDeathStalkerV2ProTKLWired):
+    """
+    Class for the Razer DeathStalker V2 Pro TKL (Wireless)
+    """
+    USB_PID = 0x0296
+
+
 class RazerBlackWidowChromaOverwatch(_RippleKeyboard):
     """
     Class for the Razer BlackWidow Chroma (Overwatch)
@@ -1283,7 +1368,7 @@ class RazerBlade2018Mercury(_RippleKeyboard):
     DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/1552/1552-blade-stealth-mercury-white.png"
 
 
-class RazerBlade2018Base(_RippleKeyboard):
+class RazerBlade2018Base(_MacroKeyboard):
     """
     Class for the Razer Blade 15 (2018) Base Model
     """
@@ -1297,7 +1382,7 @@ class RazerBlade2018Base(_RippleKeyboard):
     DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/1418/1418_blade_2018__base.png"
 
 
-class RazerBladeStealth2019(_RippleKeyboard):
+class RazerBladeStealth2019(_MacroKeyboard):
     """
     Class for the Razer Blade Stealth (2019)
     """
@@ -1311,7 +1396,7 @@ class RazerBladeStealth2019(_RippleKeyboard):
     DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/1475/1475_bladestealth13(2019).png"
 
 
-class RazerBladeStealthLate2019(_RippleKeyboard):
+class RazerBladeStealthLate2019(_MacroKeyboard):
     """
     Class for the Razer Blade Stealth (Late 2019)
     """
@@ -1325,7 +1410,7 @@ class RazerBladeStealthLate2019(_RippleKeyboard):
     DEVICE_IMAGE = "https://assets2.razerzone.com/images/blade-stealth-13/shop/stealth-l2p-1.jpg"
 
 
-class RazerBladeStealthEarly2020(_RippleKeyboard):
+class RazerBladeStealthEarly2020(_MacroKeyboard):
     """
     Class for the Razer Blade Stealth (Early 2020)
     """
@@ -1339,7 +1424,7 @@ class RazerBladeStealthEarly2020(_RippleKeyboard):
     DEVICE_IMAGE = "https://assets2.razerzone.com/images/blade-stealth-13/shop/sl25p-fhd-4.jpg"
 
 
-class RazerBladeStealthLate2020(_RippleKeyboard):
+class RazerBladeStealthLate2020(_MacroKeyboard):
     """
     Class for the Razer Blade Stealth (Late 2020)
     """
@@ -1353,7 +1438,7 @@ class RazerBladeStealthLate2020(_RippleKeyboard):
     DEVICE_IMAGE = "https://assets2.razerzone.com/images/blade-stealth-13/shop/sl25p-fhd-4.jpg"
 
 
-class RazerBook2020(_RippleKeyboard):
+class RazerBook2020(_MacroKeyboard):
     """
     Class for the Razer Book (2020)
     """
@@ -1405,7 +1490,7 @@ class RazerBladeMid2019Mercury(_RippleKeyboard):
     DEVICE_IMAGE = "https://assets2.razerzone.com/images/blade-15/shop/blade15-mercury-1.jpg"
 
 
-class RazerBlade2019Base(_RippleKeyboard):
+class RazerBlade2019Base(_MacroKeyboard):
     """
     Class for the Razer Blade 15 (Mid 2019) Base Model
     """
@@ -1419,7 +1504,7 @@ class RazerBlade2019Base(_RippleKeyboard):
     DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/1518/1518_blade15_mid2019-base.png"
 
 
-class RazerBladeEarly2020Base(_RippleKeyboard):
+class RazerBladeEarly2020Base(_MacroKeyboard):
     """
     Class for the Razer Blade Base (Early 2020)
     """
@@ -1663,7 +1748,7 @@ class RazerBlade17ProEarly2021(_RippleKeyboard):
     DEVICE_IMAGE = "https://dl.razerzone.com/src/4025-16-EN-v1.png"
 
 
-class RazerBladeEarly2021Base(_RippleKeyboard):
+class RazerBladeEarly2021Base(_MacroKeyboard):
     """
     Class for the Razer Blade Base (Early 2021)
     """
@@ -1678,6 +1763,21 @@ class RazerBladeEarly2021Base(_RippleKeyboard):
     DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/1756/blade-15-base-2021-rz09-0369x.png"
 
 
+class RazerBladeEarly2022Base(_MacroKeyboard):
+    """
+    Class for the Razer Blade Base (Early 2022)
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*Razer_Blade(-if01)?-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x027A
+    METHODS = ['get_device_type_keyboard', 'set_static_effect', 'set_spectrum_effect',
+               'set_reactive_effect', 'set_none_effect', 'set_breath_random_effect', 'set_breath_single_effect',
+               'set_breath_dual_effect']
+
+    DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/1756/blade-15-base-2021-rz09-0369x.png"
+
+
 class RazerBlade172022(_RippleKeyboard):
     """
     Class for the Razer Blade 17 (2022)
@@ -1697,6 +1797,25 @@ class RazerBlade172022(_RippleKeyboard):
     DEVICE_IMAGE = "https://dl.razerzone.com/src/5896/5896-1-en-v2.png"
 
 
+class RazerBlade142022(_RippleKeyboard):
+    """
+    Class for the Razer Blade 14 (2022)
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*Razer_Blade(-if01)?-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x028C
+    HAS_MATRIX = True
+    MATRIX_DIMS = [6, 16]
+    METHODS = ['get_device_type_keyboard', 'get_logo_active', 'set_logo_active', 'set_wave_effect', 'set_static_effect', 'set_spectrum_effect',
+               'set_reactive_effect', 'set_none_effect', 'set_breath_random_effect', 'set_breath_single_effect',
+               'set_breath_dual_effect', 'set_custom_effect', 'set_key_row',
+               'set_starlight_random_effect', 'set_starlight_single_effect', 'set_starlight_dual_effect',
+               'set_ripple_effect', 'set_ripple_effect_random_colour']
+
+    DEVICE_IMAGE = "https://dl.razerzone.com/src/5896/5896-1-en-v2.png"
+
+
 class RazerBlade15AdvancedEarly2022(_RippleKeyboard):
     """
     Class for the Razer Blade 15 Advanced (Early 2022)
@@ -1714,3 +1833,83 @@ class RazerBlade15AdvancedEarly2022(_RippleKeyboard):
                'set_ripple_effect', 'set_ripple_effect_random_colour']
 
     DEVICE_IMAGE = "https://assets2.razerzone.com/images/pnx.assets/a1ee4c5a780a401444be898fe93ade69/thumbnail-blade15-new-model.png"
+
+
+class RazerBlackWidowV4Pro(_RippleKeyboard):
+    """
+    Class for the Razer BlackWidow V4 Pro
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*Razer_Razer_BlackWidow_V4_Pro(-if01)?-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x028D
+    HAS_MATRIX = True
+    WAVE_DIRS = (1, 2)
+    MATRIX_DIMS = [8, 23]
+    POLL_RATES = [125, 250, 500, 1000, 2000, 4000, 8000]
+    METHODS = ['get_device_type_keyboard', 'set_wave_effect', 'set_wheel_effect', 'set_static_effect', 'set_spectrum_effect',
+               'set_reactive_effect', 'set_none_effect', 'set_breath_random_effect', 'set_breath_single_effect', 'set_breath_dual_effect',
+               'set_custom_effect', 'set_key_row', 'get_game_mode', 'set_game_mode', 'get_macro_mode', 'set_macro_mode',
+               'get_macro_effect', 'set_macro_effect', 'get_macros', 'delete_macro', 'add_macro',
+               'set_starlight_random_effect', 'set_starlight_single_effect', 'set_starlight_dual_effect',
+               'get_poll_rate', 'set_poll_rate', 'get_supported_poll_rates',
+               'set_ripple_effect', 'set_ripple_effect_random_colour']
+
+    DEVICE_IMAGE = "https://dl.razerzone.com/src2/9703/9703-1-en-v1.png"
+
+
+class RazerBlade152023(_RippleKeyboard):
+    """
+    Class for the Razer Blade 15 (2023)
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*Razer_Blade(-if01)?-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x029E
+    HAS_MATRIX = True
+    MATRIX_DIMS = [6, 16]
+    METHODS = ['get_device_type_keyboard', 'get_logo_active', 'set_logo_active', 'set_wave_effect', 'set_static_effect', 'set_spectrum_effect',
+               'set_reactive_effect', 'set_none_effect', 'set_breath_random_effect', 'set_breath_single_effect',
+               'set_breath_dual_effect', 'set_custom_effect', 'set_key_row',
+               'set_starlight_random_effect', 'set_starlight_single_effect', 'set_starlight_dual_effect',
+               'set_ripple_effect', 'set_ripple_effect_random_colour']
+
+    DEVICE_IMAGE = "https://dl.razerzone.com/src2/9696/9696-1-en-v2.png"
+
+
+class RazerBlade162023(_RippleKeyboard):
+    """
+    Class for the Razer Blade 16 (2023)
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*Razer_Blade(-if01)?-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x029F
+    HAS_MATRIX = True
+    MATRIX_DIMS = [6, 16]
+    METHODS = ['get_device_type_keyboard', 'get_logo_active', 'set_logo_active', 'set_wave_effect', 'set_static_effect', 'set_spectrum_effect',
+               'set_reactive_effect', 'set_none_effect', 'set_breath_random_effect', 'set_breath_single_effect',
+               'set_breath_dual_effect', 'set_custom_effect', 'set_key_row',
+               'set_starlight_random_effect', 'set_starlight_single_effect', 'set_starlight_dual_effect',
+               'set_ripple_effect', 'set_ripple_effect_random_colour']
+
+    DEVICE_IMAGE = "https://dl.razerzone.com/src/9668/9668-1-en-v2.png"
+
+
+class RazerBlade182023(_RippleKeyboard):
+    """
+    Class for the Razer Blade 18 (2023)
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*Razer_Blade(-if01)?-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x02A0
+    HAS_MATRIX = True
+    MATRIX_DIMS = [6, 16]
+    METHODS = ['get_device_type_keyboard', 'get_logo_active', 'set_logo_active', 'set_wave_effect', 'set_static_effect', 'set_spectrum_effect',
+               'set_reactive_effect', 'set_none_effect', 'set_breath_random_effect', 'set_breath_single_effect',
+               'set_breath_dual_effect', 'set_custom_effect', 'set_key_row',
+               'set_starlight_random_effect', 'set_starlight_single_effect', 'set_starlight_dual_effect',
+               'set_ripple_effect', 'set_ripple_effect_random_colour']
+
+    DEVICE_IMAGE = "https://dl.razerzone.com/src2/9676/9676-1-en-v1.png"
