@@ -77,11 +77,22 @@
 #define USB_DEVICE_ID_RAZER_NAGA_X 0x0096
 #define USB_DEVICE_ID_RAZER_DEATHADDER_ESSENTIAL_2021 0x0098
 #define USB_DEVICE_ID_RAZER_BASILISK_V3 0x0099
+#define USB_DEVICE_ID_RAZER_PRO_CLICK_MINI_RECEIVER 0x009A
 #define USB_DEVICE_ID_RAZER_DEATHADDER_V2_X_HYPERSPEED 0x009C
+#define USB_DEVICE_ID_RAZER_VIPER_MINI_SE_WIRED 0x009E
+#define USB_DEVICE_ID_RAZER_VIPER_MINI_SE_WIRELESS 0x009F
+#define USB_DEVICE_ID_RAZER_DEATHADDER_V2_LITE 0x00A1
 #define USB_DEVICE_ID_RAZER_VIPER_V2_PRO_WIRED 0x00A5
 #define USB_DEVICE_ID_RAZER_VIPER_V2_PRO_WIRELESS 0x00A6
+#define USB_DEVICE_ID_RAZER_BASILISK_V3_PRO_WIRED 0x00AA
+#define USB_DEVICE_ID_RAZER_BASILISK_V3_PRO_WIRELESS 0x00AB
+#define USB_DEVICE_ID_RAZER_COBRA_PRO 0x00B0
+#define USB_DEVICE_ID_RAZER_DEATHADDER_V3 0x00B2
+#define USB_DEVICE_ID_RAZER_HYPERPOLLING_WIRELESS_DONGLE 0x00B3
+#define USB_DEVICE_ID_RAZER_NAGA_V2_HYPERSPEED_RECEIVER 0x00B4
 #define USB_DEVICE_ID_RAZER_DEATHADDER_V3_PRO_WIRED 0x00B6
 #define USB_DEVICE_ID_RAZER_DEATHADDER_V3_PRO_WIRELESS 0x00B7
+#define USB_DEVICE_ID_RAZER_VIPER_V3_HYPERSPEED 0x00B8
 
 /* Each keyboard report has 90 bytes*/
 #define RAZER_REPORT_LEN 0x5A
